@@ -20,7 +20,6 @@ from trytond.tools import reduce_ids, grouped_slice
 
 
 __all__ = ['Work', 'WorkInvoicedProgress', 'OpenInvoice']
-__metaclass__ = PoolMeta
 
 INVOICE_METHODS = [
     ('manual', 'Manual'),
@@ -31,6 +30,7 @@ INVOICE_METHODS = [
 
 
 class Work:
+    __metaclass__ = PoolMeta
     __name__ = 'project.work'
     project_invoice_method = fields.Selection(INVOICE_METHODS,
         'Invoice Method',
@@ -205,7 +205,7 @@ class Work:
         Company = pool.get('company.company')
         Currency = pool.get('currency.currency')
 
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         table = cls.__table__()
         progress = Progress.__table__()
         invoice_line = InvoiceLine.__table__()
@@ -257,7 +257,7 @@ class Work:
         Company = pool.get('company.company')
         Currency = pool.get('currency.currency')
 
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         table = cls.__table__()
         timesheet_work = TimesheetWork.__table__()
         timesheet_line = TimesheetLine.__table__()
@@ -303,7 +303,7 @@ class Work:
     def _get_duration_timesheet(works, invoiced):
         pool = Pool()
         TimesheetLine = pool.get('timesheet.line')
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         line = TimesheetLine.__table__()
 
         durations = {}
@@ -402,7 +402,7 @@ class Work:
 
         return Invoice(
             company=self.company,
-            type='out_invoice',
+            type='out',
             journal=journal,
             party=self.party,
             invoice_address=self.party.address_get(type='invoice'),
